/*
 * Kernel version glue
 *
 * (c) 1999 Vojtech Pavlik <vojtech@suse.cz>
 *
 * This allows USB designed for the 2.3 kernel series to compile
 * on a 2.2 kernel. Not all kernel interface changes are reflected
 * here - only those needed by the USB stack.
 */

#ifndef __USB_GLUE_H
#define __USB_GLUE_H

#include <linux/proc_fs.h>
#include <linux/slab.h>
#include <linux/interrupt.h>

typedef struct wait_queue *wait_queue_head_t;
#define DECLARE_WAITQUEUE(x,y)		struct wait_queue x = { y, NULL }
#define DECLARE_WAIT_QUEUE_HEAD(x)	struct wait_queue *x = NULL
#define init_waitqueue_head(x)		do { *(x) = NULL; } while (0)

#define VID_HARDWARE_CPIA		24

#define LIST_HEAD_INIT(x)		{ &(x), &(x) }

#define __set_current_state(x)		do { current->state = x; } while (0)
#ifdef __SMP__
#define set_current_state(x)		do { mb(); __set_current_state(x); } while (0)
#else
#define set_current_state(x)		__set_current_state(x)
#endif

#define DECLARE_MUTEX(x)		struct semaphore x = MUTEX
#define DECLARE_MUTEX_LOCKED(x)		struct semaphore x = MUTEX_LOCKED
static inline void init_MUTEX (struct semaphore *sem) { sema_init(sem, 1); }
static inline void list_add_tail(struct list_head *new, struct list_head *head) { __list_add(new, head->prev, head); }

#define __exit
#define module_init(x)			int init_module(void) { return x(); }
#define module_exit(x)			void cleanup_module(void) { x(); }

#define BUG()				do { } while (0)

extern inline struct proc_dir_entry *create_proc_read_entry(const char *name,
        mode_t mode, struct proc_dir_entry *base, read_proc_t *read_proc, void * data)
{
        struct proc_dir_entry *res=create_proc_entry(name,mode,base);
        if (res) { res->read_proc=read_proc; res->data=data; }
        return res;
}

#define page_address(x)			(x | PAGE_OFFSET)

#define pci_enable_device(x)		do { } while (0)

#endif
